summaryrefslogtreecommitdiff
path: root/Master/tlpkg/TeXLive/TLTREE.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Master/tlpkg/TeXLive/TLTREE.pm')
-rw-r--r--Master/tlpkg/TeXLive/TLTREE.pm5
1 files changed, 3 insertions, 2 deletions
diff --git a/Master/tlpkg/TeXLive/TLTREE.pm b/Master/tlpkg/TeXLive/TLTREE.pm
index 535dd435f5e..7b76f1c29d1 100644
--- a/Master/tlpkg/TeXLive/TLTREE.pm
+++ b/Master/tlpkg/TeXLive/TLTREE.pm
@@ -199,8 +199,9 @@ sub _initialize_lines {
next if ($1 eq "D"); # ignore files which are removed
next if -d $entry && ! -l $entry; # keep symlinks to dirs (bin/*/man),
# ignore normal dirs.
- # collect architectures, assuming nothing is in bin/ but arch subdirs.
- if ($entry =~ m,^bin/([^/]*)/,) {
+ # collect architectures; bin/ has arch subdirs plus the plain man
+ # special case.
+ if ($entry =~ m,^bin/([^/]*)/, && $entry ne "bin/man") {
$archs{$1} = 1;
}
$self->{'_allfiles'}{$entry}{'lastchangedrev'} = $lastchanged;